@@ -22,7 +22,9 @@ mod waiter;
 
 pub use self::apiversion::ApiVersion;
 pub use self::resourceiterator::{ResourceIterator, ResourceQuery};
-pub use self::types::{FlavorRef, ImageRef, KeyPairRef, NetworkRef, PortRef,
-                      ProjectRef, Refresh, RouterRef, SubnetRef, UserRef};
 pub(crate) use self::types::IntoVerified;
+pub use self::types::{
+    FlavorRef, ImageRef, KeyPairRef, NetworkRef, PortRef, ProjectRef, Refresh, RouterRef,
+    SubnetRef, UserRef,
+};
 pub use self::waiter::DeletionWaiter;
