@@ -45,38 +45,43 @@
 // NOTE: we do not use generic deny(warnings) to avoid breakages with new
 // versions of the compiler. Add more warnings here as you discover them.
 // Taken from https://github.com/rust-unofficial/patterns/
-#![deny(const_err,
-        dead_code,
-        improper_ctypes,
-        legacy_directory_ownership,
-        missing_copy_implementations,
-        missing_debug_implementations,
-        missing_docs,
-        non_shorthand_field_patterns,
-        no_mangle_generic_items,
-        overflowing_literals,
-        path_statements ,
-        patterns_in_fns_without_body,
-        plugin_as_library,
-        private_in_public,
-        private_no_mangle_fns,
-        private_no_mangle_statics,
-        safe_extern_statics,
-        trivial_casts,
-        trivial_numeric_casts,
-        unconditional_recursion,
-        unions_with_drop_fields,
-        unsafe_code,
-        unused,
-        unused_allocation,
-        unused_comparisons,
-        unused_doc_comments,
-        unused_import_braces,
-        unused_parens,
-        unused_qualifications,
-        unused_results,
-        while_true)]
+#![deny(
+    const_err,
+    dead_code,
+    improper_ctypes,
+    legacy_directory_ownership,
+    missing_copy_implementations,
+    missing_debug_implementations,
+    missing_docs,
+    non_shorthand_field_patterns,
+    no_mangle_generic_items,
+    overflowing_literals,
+    path_statements,
+    patterns_in_fns_without_body,
+    plugin_as_library,
+    private_in_public,
+    safe_extern_statics,
+    trivial_casts,
+    trivial_numeric_casts,
+    unconditional_recursion,
+    unions_with_drop_fields,
+    unsafe_code,
+    unused,
+    unused_allocation,
+    unused_comparisons,
+    unused_doc_comments,
+    unused_import_braces,
+    unused_parens,
+    unused_qualifications,
+    unused_results,
+    while_true
+)]
 #![allow(unused_extern_crates)]
+#![allow(
+    clippy::new_ret_no_self,
+    clippy::should_implement_trait,
+    clippy::wrong_self_convention
+)]
 
 extern crate chrono;
 extern crate dirs;
@@ -93,7 +98,6 @@ extern crate serde_json;
 extern crate serde_yaml;
 extern crate waiter;
 
-
 #[allow(unused_macros)]
 macro_rules! transparent_property {
     ($(#[$attr:meta])* $name:ident: ref $type:ty) => (
@@ -111,7 +115,6 @@ macro_rules! transparent_property {
     );
 }
 
-
 #[allow(unused_macros)]
 macro_rules! query_filter {
     ($(#[$attr:meta])* $func:ident -> $name:ident) => (
@@ -157,7 +160,6 @@ macro_rules! query_filter {
     );
 }
 
-
 #[allow(unused_macros)]
 macro_rules! creation_inner_field {
 
@@ -215,7 +217,6 @@ macro_rules! creation_inner_field {
 
 }
 
-
 #[allow(unused_macros)]
 macro_rules! creation_inner_vec {
 
@@ -257,7 +258,6 @@ macro_rules! creation_inner_vec {
 
 }
 
-
 #[allow(unused_macros)]
 macro_rules! update_field {
 
@@ -322,7 +322,6 @@ macro_rules! update_field {
 
 }
 
-
 #[allow(unused_macros)]
 macro_rules! update_field_mut {
 
@@ -361,7 +360,6 @@ macro_rules! save_option_fields {
     }
 }
 
-
 #[allow(unused_macros)]
 macro_rules! save_fields {
     ($self:ident -> $target:ident: $($field:ident)+) => {
@@ -373,7 +371,6 @@ macro_rules! save_fields {
     }
 }
 
-
 #[allow(unused_macros)]
 macro_rules! protocol_enum {
     {$(#[$attr:meta])* enum $name:ident: $carrier:ty {
@@ -408,7 +405,7 @@ macro_rules! protocol_enum {
             fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
                     where S: ::serde::ser::Serializer {
                 match self {
-                    $(&$name::$item => $val),+,
+                    $($name::$item => $val),+,
                     _ => unreachable!()
                 }.serialize(serializer)
             }
@@ -480,7 +477,6 @@ macro_rules! protocol_enum {
     );
 }
 
-
 pub mod auth;
 mod cloud;
 pub mod common;
@@ -495,10 +491,9 @@ pub mod network;
 pub mod session;
 mod utils;
 
-pub use cloud::Cloud;
-pub use common::Refresh;
-pub use error::{Error, ErrorKind, Result};
-
+pub use crate::cloud::Cloud;
+pub use crate::common::Refresh;
+pub use crate::error::{Error, ErrorKind, Result};
 
 /// Sorting request.
 #[derive(Debug, Clone)]
@@ -506,14 +501,14 @@ pub enum Sort<T: Into<String>> {
     /// Sorting by given field in ascendant order.
     Asc(T),
     /// Sorting by given field in descendant order.
-    Desc(T)
+    Desc(T),
 }
 
 impl<T: Into<String>> Into<(String, String)> for Sort<T> {
     fn into(self) -> (String, String) {
         match self {
             Sort::Asc(val) => (val.into(), String::from("asc")),
-            Sort::Desc(val) => (val.into(), String::from("desc"))
+            Sort::Desc(val) => (val.into(), String::from("desc")),
         }
     }
 }
