@@ -16,16 +16,14 @@
 
 use std::cell::Ref;
 
-use log;
 use reqwest::{Method, RequestBuilder, Response, Url};
 use serde::de::DeserializeOwned;
 
-use super::{Error, ErrorKind, Result};
 use super::auth::AuthMethod;
-use super::common::ApiVersion;
 use super::common::protocol::ServiceInfo;
+use super::common::ApiVersion;
 use super::utils;
-
+use super::{Error, ErrorKind, Result};
 
 /// Trait representing a service type.
 pub trait ServiceType {
@@ -33,16 +31,29 @@ pub trait ServiceType {
     fn catalog_type() -> &'static str;
 
     /// Check whether this service type is compatible with the given major version.
-    fn major_version_supported(_version: ApiVersion) -> bool { true }
+    fn major_version_supported(_version: ApiVersion) -> bool {
+        true
+    }
 
     /// Update the request to include the API version headers.
     ///
     /// The default implementation fails with `IncompatibleApiVersion`.
-    fn set_api_version_headers(_request: RequestBuilder, _version: ApiVersion)
-            -> Result<RequestBuilder> {
-        Err(Error::new(ErrorKind::IncompatibleApiVersion,
-                       format!("The {} service does not support API versions",
-                               Self::catalog_type())))
+    fn set_api_version_headers(
+        _request: RequestBuilder,
+        _version: ApiVersion,
+    ) -> Result<RequestBuilder> {
+        Err(Error::new(
+            ErrorKind::IncompatibleApiVersion,
+            format!(
+                "The {} service does not support API versions",
+                Self::catalog_type()
+            ),
+        ))
+    }
+
+    /// Whether this service supports version discovery at all.
+    fn version_discovery_supported() -> bool {
+        true
     }
 }
 
@@ -52,13 +63,19 @@ pub trait RequestBuilderExt {
     fn send_checked(self) -> Result<Response>;
 
     /// Send a request and discard the results.
-    fn commit(self) -> Result<()> where Self: Sized {
+    fn commit(self) -> Result<()>
+    where
+        Self: Sized,
+    {
         let _ = self.send_checked()?;
         Ok(())
     }
 
     /// Send a request and receive a JSON back.
-    fn receive_json<T: DeserializeOwned>(self) -> Result<T> where Self: Sized {
+    fn receive_json<T: DeserializeOwned>(self) -> Result<T>
+    where
+        Self: Sized,
+    {
         self.send_checked()?.json().map_err(From::from)
     }
 }
@@ -78,13 +95,16 @@ fn _log(mut resp: Response) -> Response {
         };
 
         // TODO(dtantsur): proper error parsing
-        trace!("HTTP request to {} returned {}; error: {:?}",
-               resp.url(), resp.status(), details);
+        trace!(
+            "HTTP request to {} returned {}; error: {:?}",
+            resp.url(),
+            resp.status(),
+            details
+        );
     }
     resp
 }
 
-
 /// An OpenStack API session.
 ///
 /// The session object serves as a wrapper around an HTTP(s) client, handling
@@ -95,10 +115,9 @@ fn _log(mut resp: Response) -> Response {
 pub struct Session {
     auth: Box<AuthMethod>,
     cached_info: utils::MapCache<&'static str, ServiceInfo>,
-    endpoint_interface: String
+    endpoint_interface: String,
 }
 
-
 impl Session {
     /// Create a new session with a given authentication plugin.
     ///
@@ -109,7 +128,7 @@ impl Session {
         Session {
             auth: Box::new(auth_method),
             cached_info: utils::MapCache::new(),
-            endpoint_interface: ep
+            endpoint_interface: ep,
         }
     }
 
@@ -117,14 +136,18 @@ impl Session {
     ///
     /// This call clears the cached service information.
     pub fn set_endpoint_interface<S>(&mut self, endpoint_interface: S)
-            where S: Into<String> {
+    where
+        S: Into<String>,
+    {
         self.cached_info = utils::MapCache::new();
         self.endpoint_interface = endpoint_interface.into();
     }
 
     /// Convert this session into one using the given endpoint interface.
-    pub fn with_endpoint_interface<S>(mut self, endpoint_interface: S)
-            -> Session where S: Into<String> {
+    pub fn with_endpoint_interface<S>(mut self, endpoint_interface: S) -> Session
+    where
+        S: Into<String>,
+    {
         self.set_endpoint_interface(endpoint_interface);
         self
     }
@@ -140,38 +163,54 @@ impl Session {
     }
 
     /// Construct and endpoint for the given service from the path.
-    pub fn get_endpoint<Srv: ServiceType>(&self, path: &[&str])
-            -> Result<Url> {
+    pub fn get_endpoint<Srv: ServiceType>(&self, path: &[&str]) -> Result<Url> {
         let info = self.get_service_info_ref::<Srv>()?;
         Ok(utils::url::extend(info.root_url.clone(), path))
     }
 
     /// Get the currently used major version from the given service.
+    ///
+    /// Can return `IncompatibleApiVersion` if the service does not support
+    /// API version discovery at all.
     pub fn get_major_version<Srv: ServiceType>(&self) -> Result<ApiVersion> {
         let info = self.get_service_info_ref::<Srv>()?;
-        Ok(info.major_version)
+        info.major_version.ok_or_else(|| {
+            Error::new(
+                ErrorKind::IncompatibleApiVersion,
+                format!(
+                    "{} service does not expose major version",
+                    Srv::catalog_type()
+                ),
+            )
+        })
     }
 
     /// Get minimum/maximum API (micro)version information.
     ///
     /// Returns `None` if the range cannot be determined, which usually means
     /// that microversioning is not supported.
-    pub fn get_api_versions<Srv: ServiceType>(&self)
-            -> Result<Option<(ApiVersion, ApiVersion)>> {
+    pub fn get_api_versions<Srv: ServiceType>(&self) -> Result<Option<(ApiVersion, ApiVersion)>> {
         let info = self.get_service_info_ref::<Srv>()?;
         match (info.minimum_version, info.current_version) {
             (Some(min), Some(max)) => Ok(Some((min, max))),
-            _ => Ok(None)
+            _ => Ok(None),
         }
     }
 
     /// Make an HTTP request to the given service.
-    pub fn request<Srv: ServiceType>(&self, method: Method, path: &[&str],
-                                     api_version: Option<ApiVersion>)
-            -> Result<RequestBuilder> {
+    pub fn request<Srv: ServiceType>(
+        &self,
+        method: Method,
+        path: &[&str],
+        api_version: Option<ApiVersion>,
+    ) -> Result<RequestBuilder> {
         let url = self.get_endpoint::<Srv>(path)?;
-        trace!("Sending HTTP {} request to {} with API version {:?}",
-               method, url, api_version);
+        trace!(
+            "Sending HTTP {} request to {} with API version {:?}",
+            method,
+            url,
+            api_version
+        );
         let mut builder = self.auth.request(method, url)?;
         if let Some(version) = api_version {
             builder = Srv::set_api_version_headers(builder, version)?;
@@ -180,30 +219,45 @@ impl Session {
     }
 
     /// Start a GET request.
-    pub fn get<Srv: ServiceType>(&self, path: &[&str], api_version: Option<ApiVersion>)
-            -> Result<RequestBuilder> {
+    pub fn get<Srv: ServiceType>(
+        &self,
+        path: &[&str],
+        api_version: Option<ApiVersion>,
+    ) -> Result<RequestBuilder> {
         self.request::<Srv>(Method::GET, path, api_version)
     }
 
     /// Start a POST request.
-    pub fn post<Srv: ServiceType>(&self, path: &[&str], api_version: Option<ApiVersion>)
-            -> Result<RequestBuilder> {
+    pub fn post<Srv: ServiceType>(
+        &self,
+        path: &[&str],
+        api_version: Option<ApiVersion>,
+    ) -> Result<RequestBuilder> {
         self.request::<Srv>(Method::POST, path, api_version)
     }
 
     /// Start a PUT request.
-    pub fn put<Srv: ServiceType>(&self, path: &[&str], api_version: Option<ApiVersion>)
-            -> Result<RequestBuilder> {
+    pub fn put<Srv: ServiceType>(
+        &self,
+        path: &[&str],
+        api_version: Option<ApiVersion>,
+    ) -> Result<RequestBuilder> {
         self.request::<Srv>(Method::PUT, path, api_version)
     }
 
     /// Start a DELETE request.
-    pub fn delete<Srv: ServiceType>(&self, path: &[&str], api_version: Option<ApiVersion>)
-            -> Result<RequestBuilder> {
+    pub fn delete<Srv: ServiceType>(
+        &self,
+        path: &[&str],
+        api_version: Option<ApiVersion>,
+    ) -> Result<RequestBuilder> {
         self.request::<Srv>(Method::DELETE, path, api_version)
     }
 
-    fn ensure_service_info<Srv>(&self) -> Result<()> where Srv: ServiceType {
+    fn ensure_service_info<Srv>(&self) -> Result<()>
+    where
+        Srv: ServiceType,
+    {
         self.cached_info.ensure_value(Srv::catalog_type(), |_| {
             self.get_catalog_endpoint(Srv::catalog_type())
                 .and_then(|ep| ServiceInfo::fetch::<Srv>(ep, self.auth_method()))
@@ -213,13 +267,17 @@ impl Session {
     }
 
     fn get_catalog_endpoint<S>(&self, service_type: S) -> Result<Url>
-            where S: Into<String> {
-        self.auth.get_endpoint(service_type.into(),
-                               Some(self.endpoint_interface.clone()))
+    where
+        S: Into<String>,
+    {
+        self.auth
+            .get_endpoint(service_type.into(), Some(self.endpoint_interface.clone()))
     }
 
-    pub(crate) fn get_service_info_ref<Srv>(&self)
-            -> Result<Ref<ServiceInfo>> where Srv: ServiceType {
+    pub(crate) fn get_service_info_ref<Srv>(&self) -> Result<Ref<ServiceInfo>>
+    where
+        Srv: ServiceType,
+    {
         self.ensure_service_info::<Srv>()?;
         Ok(self.cached_info.get_ref(&Srv::catalog_type()).unwrap())
     }
@@ -229,13 +287,13 @@ impl ServiceInfo {
     /// Whether this service supports the given API version.
     ///
     /// Defaults to false if cannot be determined.
-    #[allow(dead_code)]  // unused with --no-default-features
+    #[allow(dead_code)] // unused with --no-default-features
     pub fn supports_api_version(&self, version: ApiVersion) -> bool {
         match (self.minimum_version, self.current_version) {
             (Some(min), Some(max)) => min <= version && max >= version,
             (None, Some(current)) => current == version,
             (Some(min), None) => version >= min,
-            _ => false
+            _ => false,
         }
     }
 }
